%define anolis_release 4

Name:           lzo
Version:        2.10
Release:        %{anolis_release}%{?dist}
Summary:        Data compression library with very fast (de)compression
License:        GPLv2+
URL:            http://www.oberhumer.com/opensource/lzo/

Source0:        http://www.oberhumer.com/opensource/lzo/download/%{name}-%{version}.tar.gz

BuildRequires:  make gcc
BuildRequires:  zlib-devel

%description
The LZO library is a powerful compression and decompression library that
is widely used in various applications due to its high speed, low memory
usage, and portability. It implements the Lempel-Ziv-Oberhumer algorithm
and provides a simple and easy-to-use API for compressing and decompressing data.

The library offers several compression levels and algorithms, allowing
developers to choose the most appropriate combination of compression speed
and efficiency for their specific needs. It also supports streaming
compression and decompression, which is essential for applications that
require real-time data processing.

Additionally, the LZO library operates on various platforms, including
embedded devices, desktop computers, and servers, making it highly portable.
It provides excellent error detection and recovery mechanisms, ensuring that
compressed data is decompressed without any loss or corruption.

In summary, the LZO library is a reliable, efficient, and portable data
compression library that is suitable for various applications that require
fast data transfer and storage optimization.

%package minilzo
Summary:        Mini version of lzo for apps which don't need the full version

%description minilzo
Minilzo is a small, lightweight implementation of the Lempel-Ziv-Oberhumer (LZO)
compression algorithm. It is designed to provide fast and efficient compression
and decompression of data with a minimal memory footprint.

The library is written in C and is therefore highly portable, allowing it to be
used on a wide range of platforms and devices. It offers several compression
levels and algorithms, allowing developers to choose the most appropriate
combination of compression speed and efficiency for their specific needs.

In addition to its small size and high performance, minilzo also includes error
detection and recovery mechanisms, ensuring that compressed data is decompressed
without any loss or corruption.

Overall, minilzo is an ideal choice for applications that require fast and
efficient compression and decompression of data, particularly those with limited
memory resources or operating on embedded devices where space and processing
power are at a premium.

%package devel
Summary:        Development files for the lzo library
Requires:       %{name} = %{version}-%{release}
Requires:       %{name}-minilzo = %{version}-%{release}
Requires:       zlib-devel

%description devel
LZO is a portable lossless data compression library written in ANSI C.
It offers pretty fast compression and very fast decompression.
This package contains development files needed for lzo.

%package doc
Summary:        Documentation files for %{name}
Requires:       %{name} = %{version}-%{release}
BuildArch:      noarch

%description    doc
The %{name}-doc package contains documentation files for %{name}.

%prep
%autosetup -p1
for i in asm/i386/src_gas/*.S; do
  echo '.section .note.GNU-stack,"",@progbits' >> $i
done

%build
%configure --disable-dependency-tracking --disable-static --enable-shared
%{make_build} CFLAGS+=-fno-strict-aliasing

# This step is for building minilzo (bz 439979)
gcc %{optflags} -fpic -Iinclude/lzo -o minilzo/minilzo.o -c minilzo/minilzo.c
gcc -g -shared -Wl,-z,now -o libminilzo.so.0 -Wl,-soname,libminilzo.so.0 minilzo/minilzo.o

%install
%{make_install}

# Copy files to destination
install -m 0755 libminilzo.so.0 $RPM_BUILD_ROOT%{_libdir}
install -m 0644 -p minilzo/minilzo.h $RPM_BUILD_ROOT%{_includedir}/lzo
ln -s libminilzo.so.0 $RPM_BUILD_ROOT%{_libdir}/libminilzo.so

#Remove doc
rm -rf $RPM_BUILD_ROOT%{_datadir}/doc/lzo

%generate_compatibility_deps

%check
make check test

# Files for lzo package
%files
%dir %{abidir}
%{_libdir}/liblzo2.so.*
%{abidir}/liblzo2.dump
%{abidir}/libminilzo.dump
%license COPYING

# Files for devel package
%files devel
%{_includedir}/lzo
%{_libdir}/lib*lzo*.so
%{_libdir}/pkgconfig/lzo2.pc
%doc doc/LZOAPI.TXT doc/LZO.FAQ doc/LZO.TXT

# Files for minilzo package
%files minilzo
%license COPYING
%doc minilzo/README.LZO
%{_libdir}/libminilzo.so.0

%files doc
%doc AUTHORS THANKS NEWS

%changelog
* Wed Apr 12 2023 Xuchun Shang <xuchun.shang@linux.alibaba.com> - 2.10-4
- Update some description

* Wed Feb 08 2023 Xuchun Shang <xuchun.shang@linux.alibaba.com> - 2.10-3
- add abi file

* Fri Sep 30 2022 mgb01105731 <mgb01105731@alibaba-inc.com> - 2.10-2
- add doc package

* Thu  Mar 03 2022 Hongwei Qin <qhw01063182@alibaba-inc.com> - 2.10-1
- upstream version 2.10 and fix configure failed
- Init for Anolis OS 23
